@@ -5,17 +5,19 @@
 * Botan is released under the Simplified BSD License (see license.txt)
 */
 
-#ifndef BOTAN_CAST128_H__
-#define BOTAN_CAST128_H__
+#ifndef BOTAN_CAST128_H_
+#define BOTAN_CAST128_H_
 
 #include <botan/block_cipher.h>
 
+BOTAN_FUTURE_INTERNAL_HEADER(cast128.h)
+
 namespace Botan {
 
 /**
 * CAST-128
 */
-class BOTAN_DLL CAST_128 final : public Block_Cipher_Fixed_Params<8, 11, 16>
+class BOTAN_PUBLIC_API(2,0) CAST_128 final : public Block_Cipher_Fixed_Params<8, 11, 16>
    {
    public:
       void encrypt_n(const uint8_t in[], uint8_t out[], size_t blocks) const override;
